@@ -9,7 +9,7 @@ class ProjyTemplateTemplate(ProjyTemplate):
     """ Projy template class for ProjyTemplate. """
 
     def __init__(self):
-        self.project_name = None
+        ProjyTemplate.__init__(self)
 
 
     def files(self):
